@@ -40,26 +40,28 @@ class JobTask(VizTools):
         self._info = self.info
 
     def __repr__(self):
-        info = self.info[0]
         return (
-            f"JobTask(name: {info['name']}, jobtask_id: {self.jobtask_id}, "
-            f"status: {info['status']}, startedAt: {info['startedAt']}, "
-            f"finishedAt: {info['finishedAt']}, job_name: {info['name']}, "
-            f"block_name: {info['block']['name']}, block_version: {info['blockVersion']}"
+            f"JobTask(name: {self._info['name']}, jobtask_id: {self.jobtask_id}, "
+            f"status: {self._info['status']}, startedAt: {self._info['startedAt']}, "
+            f"finishedAt: {self._info['finishedAt']}, job_name: {self._info['name']}, "
+            f"block_name: {self._info['block']['name']}, block_version: {self._info['blockVersion']}"
         )
 
     @property
     def info(self) -> dict:
         """
-        Gets the jobtask metadata information.
+        Gets and updates the jobtask metadata information.
         """
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/jobs/{self.job_id}"
             f"/tasks/"
         )
         response_json = self.auth._request(request_type="GET", url=url)
-        self._info = response_json["data"]
-        return response_json["data"]
+        info_all_jobtasks = response_json["data"]
+        self._info = next(
+            item for item in info_all_jobtasks if item["id"] == self.jobtask_id
+        )
+        return self._info
 
     def get_results_json(self, as_dataframe: bool = False) -> Union[dict, GeoDataFrame]:
         """
