@@ -308,92 +308,47 @@ def any_vector_to_fc(
 
 
 def fc_to_query_geometry(
-    fc: Union[dict, FeatureCollection],
-    geometry_operation: str,
-    squash_multiple_features: str = "union",
+    fc: Union[dict, FeatureCollection], geometry_operation: str
 ) -> Union[List, dict]:
     """
-    From a feature collection (one or multiple polygons) & any geometry_operation,
-    gets a single query geometry for the workflow parameters.
-    Returns either a list of bounds or a geojson Polygon (as dict) depending on geometry_operation.
-    If an input fc with multiple features is provided, it gets squashed to a single
-    output geometry, either by taking the first geometry or the union (footprint) of all geometries,
-    depending on handle_multiple_features.
-
-    Examples (geometry & geometry_operation > always returns a single feature):
-        Single input geometries:
-            - feature & "intersects/contains" > same as input feature
-            - feature & "bbox" > rectangular feature that is the bbox of the input feature
-        Multiple input geometries:
-            - features & "intersects/contains" > feature of first object in fc or union
-                of fc (depending on "handle_multiple_features")
-            - features & "bbox" > rectangular feature of first object in fc or union of
-                fc (depending on "handle_multiple_features")
+    From a feature collection with a single feature, depending on the geometry_operation,
+    returns the feature as a list of bounds coordinates or a geojson Polygon (as dict).
 
     Args:
         fc: feature collection
         geometry_operation: One of "bbox", "intersects", "contains".
-        squash_multiple_features: One of "union" (default, footprint of all features)
-            or "first" (takes the first feature.
 
     Returns:
-
+        The feature as a list of bounds coordinates or a geojson Polygon (as dict)
     """
-    if geometry_operation not in ["bbox", "intersects", "contains"]:
-        raise ValueError(
-            "geometry_operation needs to be one of bbox",
-            "intersects",
-            "contains",
-        )
     try:
         if fc["type"] != "FeatureCollection":
             raise ValueError("Geometry argument only supports Feature Collections!")
     except (KeyError, TypeError) as e:
         raise ValueError("Geometry argument only supports Feature Collections!") from e
 
-    # TODO: Handle multipolygons
+    geometry_error = "The provided geometry {}, UP42 only accepts single geometries."
+    if len(fc["features"]) != 1:
+        logger.info(geometry_error.format("contains multiple geometries"))
+        raise ValueError(geometry_error.format("contains multiple geometries"))
 
-    # With the now uniform feature collection, decide to return a feature or list of bounds (bbox).
-    if len(fc["features"]) == 1:
-        f = fc["features"][0]
-        if geometry_operation == "bbox":
-            try:
-                query_geometry = list(f["bbox"])
-            except KeyError:
-                query_geometry = list(shapely.geometry.shape(f["geometry"]).bounds)
-        elif geometry_operation in ["intersects", "contains"]:
-            query_geometry = f["geometry"]
-    # In case of multiple geometries transform the feature collection a single aoi
-    # geometry via handle_multiple_features method.
+    feature = fc["features"][0]
+    if feature["geometry"]["type"] == "MultiPolygon":
+        logger.info(geometry_error.format("is a MultiPolygon"))
+        raise ValueError(geometry_error.format("is a MultiPolygon"))
+
+    if geometry_operation == "bbox":
+        try:
+            query_geometry = list(feature["bbox"])
+        except KeyError:
+            query_geometry = list(shapely.geometry.shape(feature["geometry"]).bounds)
+    elif geometry_operation in ["intersects", "contains"]:
+        query_geometry = feature["geometry"]
     else:
-        logger.info(
-            f"The provided geometry contains multiple geometries, "
-            f"the {squash_multiple_features} feature is taken instead."
+        raise ValueError(
+            "geometry_operation needs to be one of bbox, intersects or contains!",
         )
-        if geometry_operation == "bbox":
-            if squash_multiple_features == "union":
-                try:
-                    query_geometry = list(fc["bbox"])
-                except KeyError:
-                    query_geometry = list(
-                        GeoDataFrame.from_features(fc, crs=4326).total_bounds
-                    )
-            elif squash_multiple_features == "first":
-                try:
-                    query_geometry = fc["features"][0]["bbox"]
-                except KeyError:
-                    query_geometry = list(
-                        shapely.geometry.shape(fc["features"][0]["geometry"]).bounds
-                    )
-        elif geometry_operation in [
-            "intersects",
-            "contains",
-        ]:  # pylint: disable=no-else-raise
-            if squash_multiple_features == "union":
-                union_poly = GeoDataFrame.from_features(fc, crs=4326).unary_union
-                query_geometry = shapely.geometry.mapping(union_poly)
-            elif squash_multiple_features == "first":
-                query_geometry = fc["features"][0]["geometry"]
+
     return query_geometry
 
 
